from tg.configuration import milestones

import logging
log = logging.getLogger('tgext.celery')


# This is the entry point of your extension, will be called
# both when the user plugs the extension manually or through tgext.pluggable
# What you write here has the same effect as writing it into app_cfg.py
# So it is possible to plug other extensions you depend on.
def plugme(configurator, options=None, **kwargs):
    if options is None:
        options = {}
    options.update(kwargs)

    log.info('Setting up tgext.celery extension...')
    milestones.config_ready.register(SetupExtension(configurator, options))

    # This is required to be compatible with the
    # tgext.pluggable interface
    return dict(appid='tgext.celery')


# Most of your extension initialization should probably happen here,
# where it's granted that .ini configuration file has already been loaded
# in tg.config but you can still register hooks or other milestones.
class SetupExtension(object):
    def __init__(self, configurator, options):
        self.configurator = configurator
        self.celery_config = options.get('celery_config')

    def __call__(self):
        from tg import config
        from tg.support.converters import aslist, asint
        from tg.configuration.utils import coerce_config
        config['celery_configuration_object'] = (coerce_config(config, 'celery.', {
            'CELERY_INCLUDE': aslist,
            'CELERY_ACCEPT_CONTENT': aslist,
            'CELERYD_CONCURRENCY': asint,
        }))
        config['celery_configuration_object'].update(self.celery_config)

    def on_startup(self):
        log.info('+ Application Running!')

from .celery import celery_app



from __future__ import absolute_import

from celery import Celery
from celery.backends.mongodb import MongoBackend
from celery.loaders.app import AppLoader


class TgCeleryAppLoader(AppLoader):
    override_backends = {
        'mongodb': 'tgext.celery.celery:TgMongoBackend',
    }


class TgMongoBackend(MongoBackend):
    def __init__(self, *args, **kwargs):
        super(TgMongoBackend, self).__init__(*args, **kwargs)
        self.options.pop('max_pool_size', None)
        self.options.pop('auto_start_request', None)


celery_app = Celery('celery_app', loader=TgCeleryAppLoader)



from setuptools import setup, find_packages
import sys, os

here = os.path.abspath(os.path.dirname(__file__))
try:
    README = open(os.path.join(here, 'README.rst')).read()
except IOError:
    README = ''

version = "0.1.0"

setup(
    name='tgext.celery',
    version=version,
    description="",
    long_description=README,
    classifiers=[],  # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    keywords='turbogears2.extension',
    author='Vincenzo Castiglia',
    author_email='vincenzo.castiglia@axant.it',
    url='https://github.com/axant/tgext.celery.git',
    license='MIT',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    namespace_packages = ['tgext'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "TurboGears2 >= 2.3.11",
        "gearbox",
        "PasteDeploy",
        "celery[mongodb]==3.1",
        "threadpool",
    ],
    entry_points={
        'gearbox.commands': [
            'celerybeat = tgext.celery.commands:CeleryBeatCommand',
            'celeryworker = tgext.celery.commands:CeleryWorkerCommand',
        ],
    },
)
